cabinetry
==============================

.. toctree::
    :hidden:
    :maxdepth: 1

    core
    advanced
    config
    cli
    api
    license

``cabinetry`` is a tool to build and steer (profile likelihood) template fits with applications in high energy physics in mind.
It acts as an interface to many powerful tools to make it easier for an analyzer to run their statistical inference pipeline.

This documentation can be viewed `on Read the Docs <https://cabinetry.readthedocs.io/>`_ or locally via

.. code-block:: bash

    sphinx-build docs docs/_build
    open docs/_build/index.html

It contains a description of the ``cabinetry`` configuration file schema, as well as the public facing API.

See the `README on github <https://github.com/alexander-held/cabinetry/blob/master/README.md>`_ for an example of using ``cabinetry``.

Acknowledgements
----------------
This work was supported by the U.S. National Science Foundation (NSF) cooperative agreement `OAC-1836650 (IRIS-HEP) <https://nsf.gov/awardsearch/showAward?AWD_ID=1836650>`_.
